package cmdTemplate

import (
    u "nexus-client/utils"
    g "nexus-client/globals"
)

type ExportDisk struct {
    Name string
}

const outputFile = "disk.qcow"

func (cmd *ExportDisk)GetName() string {
    return cmd.Name
}

func (cmd *ExportDisk)GetDesc() []string {
    return []string{
        "Exports a template's disk.",
        "Requires TPL_READFS or TPL_READFS_ANY user capability."}
}

func (cmd *ExportDisk)PrintUsage() {
    for _, desc := range cmd.GetDesc() {
        u.PrintlnErr(desc)
    }
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("USAGE: ",cmd.GetName()," ID file")
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("ID      ID of the template for which the disk must be exported.")
    u.PrintlnErr("file    Name of the file to save the disk into.")
}

func (cmd *ExportDisk)Run(args []string) int {
    client := g.GetInstance().Client
    host := g.GetInstance().Host

    argc := len(args)
    if argc != 2 {
        cmd.PrintUsage()
        return 1
    }

    tplID := args[0]
    outputFile := args[1]
    statusCode := 0

    u.Println("Exporting disk from template \""+tplID+"\" into "+outputFile+" ...")

    resp, err := client.R().SetOutput(outputFile).Get(host+"/templates/"+tplID+"/disk")
    if err != nil {
        u.PrintlnErr("Failed: "+err.Error())
        statusCode = 1
    } else {
        if resp.IsSuccess() {
            u.Println("Successfully exported disk into "+outputFile)
        } else {
			errorMsg, _ := u.FileToString(outputFile)
            u.PrintlnErr("Failed: "+resp.Status()+": "+errorMsg)
            statusCode = 1
        }
    }

    return statusCode
}
